==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QTextLayout_FormatRange_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QTextLayout>
#include <QtCore/QVariant>
#include <QtGui/qtextlayout.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextLayout_FormatRange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextLayout::FormatRange")
    QTextLayout::FormatRange *_ptr = reinterpret_cast<QTextLayout::FormatRange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QTextLayout_FormatRange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QTextLayout::FormatRange *__qt_this = new(__qtjambi_ptr) QTextLayout::FormatRange();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QTextLayout::FormatRange
void __qt_destruct_QTextLayout_FormatRange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextLayout::FormatRange")
    reinterpret_cast<QTextLayout::FormatRange*>(ptr)->~FormatRange();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextLayout::FormatRange::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_initialize_1native__Lio_qt_gui_QTextLayout_00024FormatRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLayout::FormatRange::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLayout_FormatRange_0, sizeof(QTextLayout::FormatRange), typeid(QTextLayout::FormatRange), false, &deleter_QTextLayout_FormatRange, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextLayout::FormatRange::operator==(QTextLayout::FormatRange,QTextLayout::FormatRange)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_equals_1native_1cref_1QTextLayout_1FormatRange__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLayout::FormatRange::operator==(QTextLayout::FormatRange,QTextLayout::FormatRange)", __qt_this)
        const QTextLayout::FormatRange& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QTextLayout::FormatRange>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_setFormat_1native_1cref_1QTextCharFormat__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID format0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat& __qt_format0 = QtJambiAPI::valueReferenceFromNativeId<QTextCharFormat>(format0);
        __qt_this->format = __qt_format0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_format_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat&  __qt_value = __qt_this->format;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_setLength_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint length0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->length = static_cast<int>(length0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_length_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->length;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_setStart_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint start0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->start = static_cast<int>(start0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_start_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->start;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextLayout_FormatRange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextLayout::FormatRange>("QTextLayout::FormatRange", "io/qt/gui/QTextLayout$FormatRange");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextLayout_FormatRange, {
        ConstructorInfo(&__qt_construct_QTextLayout_FormatRange_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextLayout_FormatRange);
    registerMetaType<QTextLayout::FormatRange>("QTextLayout::FormatRange");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QTextLayout_FormatRange_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QTextLayout>
#include <QtCore/QVariant>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextlayout.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextLayout_FormatRange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextLayout::FormatRange")
    QTextLayout::FormatRange *_ptr = reinterpret_cast<QTextLayout::FormatRange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new FormatRange()
void __qt_construct_QTextLayout_FormatRange(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FormatRange()")
    Q_UNUSED(__java_arguments)
    QTextLayout::FormatRange *__qt_this = new(__qtjambi_ptr) QTextLayout::FormatRange();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTextLayout::FormatRange::FormatRange()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_initialize_1native__Lio_qt_gui_QTextLayout_00024FormatRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLayout::FormatRange::FormatRange()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLayout_FormatRange, sizeof(QTextLayout::FormatRange), typeid(QTextLayout::FormatRange), false, &deleter_QTextLayout_FormatRange, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new FormatRange(QTextLayout::FormatRange)
void __qt_construct_QTextLayout_FormatRange_cref_QTextLayout_FormatRange(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FormatRange(QTextLayout::FormatRange)")
    jobject other0 = __java_arguments[0].l;
    const QTextLayout::FormatRange& __qt_other0 = qtjambi_cast<const QTextLayout::FormatRange& >(__jni_env, other0);
    QTextLayout::FormatRange *__qt_this = new(__qtjambi_ptr) QTextLayout::FormatRange(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextLayout::FormatRange::FormatRange(QTextLayout::FormatRange)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_initialize_1native__Lio_qt_gui_QTextLayout_00024FormatRange_2Lio_qt_gui_QTextLayout_00024FormatRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLayout::FormatRange::FormatRange(QTextLayout::FormatRange)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLayout_FormatRange_cref_QTextLayout_FormatRange, sizeof(QTextLayout::FormatRange), typeid(QTextLayout::FormatRange), false, &deleter_QTextLayout_FormatRange, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new FormatRange{int,int,QTextCharFormat}
void __qt_construct_QTextLayout_FormatRange_int_int_QTextCharFormat(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FormatRange{int,int,QTextCharFormat}")
    jint start0 = __java_arguments[0].i;
    Q_UNUSED(start0)
    jint length1 = __java_arguments[1].i;
    Q_UNUSED(length1)
    jobject format2 = __java_arguments[2].l;
    QTextCharFormat __qt_format2 = qtjambi_cast<QTextCharFormat >(__jni_env, format2);
    QTextLayout::FormatRange *__qt_this = new(__qtjambi_ptr) QTextLayout::FormatRange{static_cast<int>(start0), static_cast<int>(length1), __qt_format2};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextLayout::FormatRange::FormatRange{int,int,QTextCharFormat}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_initialize_1native__Lio_qt_gui_QTextLayout_00024FormatRange_2IILio_qt_gui_QTextCharFormat_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint start0,
 jint length1,
 jobject format2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextLayout::FormatRange::FormatRange{int,int,QTextCharFormat}")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = start0;
        arguments[1].i = length1;
        arguments[2].l = format2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextLayout_FormatRange_int_int_QTextCharFormat, sizeof(QTextLayout::FormatRange), typeid(QTextLayout::FormatRange), false, &deleter_QTextLayout_FormatRange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextLayout::FormatRange
void __qt_destruct_QTextLayout_FormatRange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextLayout::FormatRange")
    reinterpret_cast<QTextLayout::FormatRange*>(ptr)->~FormatRange();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextLayout::FormatRange::operator==(QTextLayout::FormatRange,QTextLayout::FormatRange)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_equals_1native_1cref_1QTextLayout_1FormatRange__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextLayout::FormatRange::operator==(QTextLayout::FormatRange,QTextLayout::FormatRange)", __qt_this)
        const QTextLayout::FormatRange& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QTextLayout::FormatRange>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_setFormat_1native_1cref_1QTextCharFormat__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID format0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat& __qt_format0 = QtJambiAPI::valueReferenceFromNativeId<QTextCharFormat>(format0);
        __qt_this->format = __qt_format0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_format_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat&  __qt_value = __qt_this->format;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_setLength_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint length0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->length = static_cast<int>(length0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_length_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->length;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_setStart_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint start0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->start = static_cast<int>(start0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_start_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->start;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextLayout_00024FormatRange_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextLayout::FormatRange *__qt_this = QtJambiAPI::objectFromNativeId<QTextLayout::FormatRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextLayout_FormatRange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextLayout::FormatRange>("QTextLayout::FormatRange", "io/qt/gui/QTextLayout$FormatRange");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextLayout_FormatRange, {
        ConstructorInfo(&__qt_construct_QTextLayout_FormatRange, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextLayout_FormatRange_cref_QTextLayout_FormatRange, "Lio/qt/gui/QTextLayout$FormatRange;")
       ,ConstructorInfo(&__qt_construct_QTextLayout_FormatRange_int_int_QTextCharFormat, "IILio/qt/gui/QTextCharFormat;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextLayout_FormatRange);
    registerMetaType<QTextLayout::FormatRange>("QTextLayout::FormatRange");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
